@@ -21,6 +21,7 @@
 #include "PaginateModel.h"
 #include "SystemFonts.h"
 #include "IconColors.h"
+#include "UnityLauncher.h"
 
 // Qt includes
 #include <QAction>
@@ -30,9 +31,7 @@
 #include <QtQml/QQmlContext>
 #include <QtQml/QQmlApplicationEngine>
 #include <QtQuick/QQuickItem>
-#include <QScreen>
 #include <qqml.h>
-#include <QQmlNetworkAccessManagerFactory>
 #include <QPointer>
 #include <QGuiApplication>
 
@@ -73,6 +72,7 @@ DiscoverMainWindow::DiscoverMainWindow(CompactMode mode)
     kdeclarative.setDeclarativeEngine(m_engine);
     kdeclarative.setupBindings();
     
+    qmlRegisterType<UnityLauncher>("org.kde.discover.app", 1, 0, "UnityLauncher");
     qmlRegisterType<PaginateModel>("org.kde.discover.app", 1, 0, "PaginateModel");
     qmlRegisterType<IconColors>("org.kde.discover.app", 1, 0, "IconColors");
     qmlRegisterSingletonType<SystemFonts>("org.kde.discover.app", 1, 0, "SystemFonts", ([](QQmlEngine*, QJSEngine*) -> QObject* { return new SystemFonts; }));
