@@ -24,10 +24,6 @@
 // KDE includes
 #include <KNewStuff3/kns3/entry.h>
 
-// Attica includes
-#include <attica/category.h>
-#include <attica/provider.h>
-
 // DiscoverCommon includes
 #include <resources/AbstractResourcesBackend.h>
 #include "Transaction/AddonList.h"
@@ -36,11 +32,9 @@
 
 class KConfigGroup;
 class KNSReviews;
+class StandardBackendUpdater;
+
 namespace KNS3 { class DownloadManager; }
-namespace Attica {
-    class ProviderManager;
-    class BaseJob;
-}
 
 class DISCOVERCOMMON_EXPORT KNSBackend : public AbstractResourcesBackend
 {
@@ -50,7 +44,6 @@ public:
     ~KNSBackend() override;
     
     void setMetaData(const QString& path) override;
-    void cancelTransaction(AbstractResource* app) override;
     void removeApplication(AbstractResource* app) override;
     void installApplication(AbstractResource* app) override;
     void installApplication(AbstractResource* app, const AddonList& addons) override;
@@ -64,23 +57,18 @@ public:
     QList<QAction*> messageActions() const override { return QList<QAction*>(); }
 
     bool isValid() const override;
-    Attica::Provider* provider() { return &m_provider; }
-    QList<AbstractResource*> upgradeablePackages() const override;
+
+    QStringList extends() const { return m_extends; }
 
     QString iconName() const { return m_iconName; }
 
 public Q_SLOTS:
     void receivedEntries(const KNS3::Entry::List& entries);
-    void startFetchingCategories();
-    void categoriesLoaded(Attica::BaseJob*);
-    void receivedContents(Attica::BaseJob*);
     void statusChanged(const KNS3::Entry& entry);
 
 private:
-    static void initManager(const QUrl& entry);
-    static QSharedPointer<Attica::ProviderManager> m_atticaManager;
     void setFetching(bool f);
-    void markInvalid();
+    void markInvalid(const QString &message);
     
     bool m_fetching;
     bool m_isValid;
@@ -88,11 +76,10 @@ private:
     QHash<QString, AbstractResource*> m_resourcesByName;
     int m_page;
     KNSReviews* const m_reviews;
-    Attica::Provider m_provider;
-    QMap<QString, Attica::Category> m_categories;
     QString m_name;
     QString m_iconName;
-    AbstractBackendUpdater* const m_updater;
+    StandardBackendUpdater* const m_updater;
+    QStringList m_extends;
 };
 
 #endif // KNSBACKEND_H
